Thomson Reuters Foundation | News, Information and Connections for Action
Author: Thomson Reuters Foundation
Description: The Thomson Reuters Foundation stands for free, independent journalism, human rights, women's empowerment, and the rule of law.

We use cookies to ensure that we give you the best experience on our website. By continuing to browse our site, you are giving your consent for us to set cookies.

However, if you would like to, you can change your cookie settings at any time. Read our cookie policy.

Under-reported stories

## Refugee influx complicates Germany's CO2 emissions goals

Under-reported stories

## Dominican Republic's top court reinstates total abortion ban

Under-reported stories

## Climate talks take a wrong turn on human rights, campaigners say

- TrustLaw Free Legal AssistanceFind out more
- Trust Women Conference30 Nov & 01 Dec 2016Find out more
- Supporting Independent JournalismFind out more

Under-reported stories

## Refugee influx complicates Germany's CO2 emissions goals

Under-reported stories

## Dominican Republic's top court reinstates total abortion ban

Under-reported stories

## Climate talks take a wrong turn on human rights, campaigners say

- TrustLaw - Free Legal AssistanceFind out more
- Trust WomenFind out more
- Supporting Independent JournalismFind out more

FEATURE

### S. Indian floods kill hospital patients, renewed rains strike fear

"The rain is not a problem now, it is the overflowing river and 30 lakes that continue to flood four districts"

#### Extreme weather

### S. Indian floods kill hospital patients, renewed rains strike fear

"The rain is not a problem now, it is the overflowing river and 30 lakes that continue to flood four districts"
TOP NEWS

- More on: Refugees and Displacement

  ### Refugee influx complicates Germany's CO2 emissions goals

  Environment Ministry says a one million increase in the population raises CO2 emissions by 6.4 million tonnes of CO2 per year
  UN climate talks 2015
  Dec 04, 10:18 GMT
  Refugees
- More on: Women's rights

  ### Dominican Republic's top court reinstates total abortion ban

  Rights groups say blanket bans on abortion leading cause of maternal mortality as women forced to have backstreet abortions
  Dec 04, 09:40 GMT
  Women's rights
- More on: Refugees and Displacement

  ### Thailand at regional meeting calls for migrant crisis framework

  Southeast Asian countries hash out framework to deal with tens of thousands of migrants, mostly from Myanmar and Bangladesh
  Dec 04, 04:12 GMT
  Refugees
- More on: Extreme Weather

  ### El Niño monthly indicator reaches level not seen since 1997-NOAA

  Weather pattern in 1997 caused heavy rains and flooding in South America and severe drought in Indonesia
  Dec 04, 01:25 GMT
  Extreme Weather

- ### Compliance on the cheap: Bangladesh garment industry struggles

- ### Counsellors prescribe TV and trees against depression in Goa

- ### Slideshow Leave no one behind: A goal for the future

THE PLAYLIST

### Compliance on the cheap: Bangladesh garment industry struggles

### Counsellors prescribe TV and trees against depression in Goa

### Leave no one behind: A goal for the future

MORE TOP NEWS

- More on: Forests

  ### Forested land larger than Iceland threatened by coal mining

  In Indonesia, 8.6 mln hectares of forest threatened by mining, nearly 9 percent of the nation's forest cover
  Forests and climate change
  Dec 03, 22:36 GMT
  Forests
- More on: Health and Disease

  ### Liberia's last two Ebola patients recover, leave hospital

  Despite the good news, new cases could still emerge in Liberia since there are 165 contacts still under quarantine
  Dec 03, 19:28 GMT
  Health & Disease
- More on: Refugees and Displacement

  ### Almost 2,000 migrants plucked from Mediterranean en route to Italy

  More than 140,000 migrants have reached Italy this year out of almost 900,000 who have arrived in Europe
  Dec 03, 19:18 GMT
  Refugees
- More on: Climate Finance

  ### Rich nations' fossil fuel subsidies exceed climate aid 40 to 1

  Developing nations have been calling for more support so that they can produce clean energy
  Dec 03, 18:55 GMT
  Climate Finance

- ### 'Loss and damage' creeps in from the cold at UN climate talks

- ### Zero hunger 'impossible' without climate protection: WFP

- ### Proposed law may remove indigenous land rights in Brazil

DON'T MISS

### 'Loss and damage' creeps in from the cold at UN climate talks

### Zero hunger 'impossible' without climate protection: WFP

### Proposed law may remove indigenous land rights in Brazil

MORE NEWS

- More on: Extreme Weather

  ### Balkan nations among those hit hardest by climate impacts in 2014

  It's not only developing countries that are at high risk of weather extremes and related losses
  UN climate talks 2015
  Dec 03, 18:51 GMT
  Extreme Weather
- More on: Refugees and Displacement

  ### Migrant electrocuted to death on Greek-Macedonian border

  While deaths at sea are common, the incident was the first casualty at the Greek-Macedonian land border
  Dec 03, 18:12 GMT
  Refugees
- More on: War and Conflict

  ### Britain joins Syria air war; Putin vows more sanctions on Turkey

  Most of the world's powers are now flying combat missions over Iraq and Syria against Islamic State
  Dec 03, 18:07 GMT
  War & Conflict
- More on:

  ### Religious leaders in India vow to end slavery

  Some 16 million slaves - nearly half the global total - live in India
  Dec 03, 17:12 GMT
  Slavery
- More on: War and Conflict

  ### U.S. calls for probe of reports of Myanmar military atrocities

  Rights group has accused Myanmar's army of committing atrocities in the country's Shan State
  Dec 03, 17:07 GMT
  War & Conflict
- More on: Adapting to Climate Change

  ### Paris climate deal to start green development charge: UNDP

  Building a low-carbon economy that can withstand climate shocks will be source of economic growth - UNDP head
  UN climate talks 2015
  Dec 03, 16:40 GMT
  Adapting to Climate
- More on: War and Conflict

  ### Regional mediation key to preventing Burundi war: US envoy

  Burundi is on the brink of civil war and will need regional mediation to avert fresh conflict
  Dec 03, 15:50 GMT
  War & Conflict

- ### 'To die or to suffer': Venezuela youth at sharp end of crime

- ### Despite treatment advances, AIDS stigma lingers in rural S. Africa

- ### Spotlight Migration and climate change

### Poll 2015: The 5 key issues facing women working in the G20

### UN climate talks 2015

### World AIDS Day 2015

### Land rights

SPOTLIGHTS

### UN climate talks 2015

### World AIDS Day 2015

### Land rights

##

- ### Proposed law may remove indigenous land rights in Brazil

- ### Displaced Nigerians prepare to leave camps, go home, but fear violence

- ### From curse to catfish: West Africa schools tackle stigma of disability

- ### In India's dry regions, crowd-funding comes to a lake's rescue

- ### Obama unveils $30 million for climate risk insurance to protect poor

VOICES

##

- ### Climate talks take a wrong turn on human rights, campaigners say

  By Megan Rowling

  Indigenous people, women's groups and trade unions decry move to weaken human rights in Paris climate deal

- ### Negotiations in Paris as drought wreaks havoc in Ethiopia

  By Kate Corcoran, Concern Worldwide

  Ethiopia is facing a drought which has put millions of its citizens in need of aid

- ### Securing women's land rights can help with climate change

  By Ranjana Das and Tzili Mor, Landesa

  Women can help build greater resilience to climate change - if they have secure rights to the land they farm

- ### Journalist reveals contentious terms of Malawi-Vale railway deal

  By Leon Malisov

  A story written by Thomson Reuters Foundation participant Rex Chikoko revealed the terms of a major railway agreement may give Malawi little cause for celebration

- ### Why garments are no longer the only industry for Bangladesh

  By Lila Caballero, ActionAid UK

  The garment industry cannot provide decent and dignified jobs for people in Bangladesh

REUTERS STORIES

- 12:17

  ### France flies surveillance missions over IS-held areas of Libya

- 12:16

  ### Israel says too early to try suspects over arson attack on ...

- 12:11

  ### New York Times censored again as Thailand marks birthday of ...

- 12:10

  ### Thai migrant crisis meeting ends without any solution on offer

NEWS IN PICTURES

##

### Most dangerous transport systems for women

### POLL: Women's rights in the Arab world

### The world's most dangerous countries for ...

POLLS

### Most dangerous transport systems for women

### POLL: Women's rights in the Arab world

### The world's most dangerous countries for women ...